@@ -14,7 +14,7 @@ from packaging import version
 from .utils.file_utils import _LazyModule, get_tf_version, pytorch_available, tf_available
 from .utils.logger import logger
 
-__version__ = 0.18
+__version__ = 0.20
 
 _IMPORT_STRUCTURE = {
     "analyzer": ["get_dd_analyzer", "build_analyzer", "load_page", "load_document"],
@@ -152,8 +152,12 @@ _IMPORT_STRUCTURE = {
         "DoctrTextlineDetector",
         "DoctrTextRecognizer",
         "FasttextLangDetector",
+        "HFLayoutLmTokenClassifierBase",
         "HFLayoutLmTokenClassifier",
+        "HFLayoutLmv2TokenClassifier",
         "HFLayoutLmSequenceClassifier",
+        "HFLayoutLmv2SequenceClassifier",
+        "HFLayoutLmv3SequenceClassifier",
         "ModelProfile",
         "ModelCatalog",
         "print_model_infos",
@@ -225,6 +229,7 @@ _IMPORT_STRUCTURE = {
         "DoctectionPipe",
         "LanguageDetectionService",
         "ImageLayoutService",
+        "get_tokenizer_from_architecture",
         "LMTokenClassifierService",
         "LMSequenceClassifierService",
         "TableSegmentationRefinementService",
@@ -320,6 +325,7 @@ _IMPORT_STRUCTURE = {
         "Relationships",
         "Languages",
         "DatasetType",
+        "update_all_types_dict",
         "get_type",
         "sub_path",
         "get_package_path",
@@ -330,6 +336,7 @@ _IMPORT_STRUCTURE = {
         "get_tqdm_default_kwargs",
         "ResizeTransform",
         "InferenceResize",
+        "normalize_image",
         "delete_keys_from_dict",
         "split_string",
         "string_to_dict",
