@@ -395,7 +395,7 @@ class Image:
         A list of attributes to suspend from as_dict creation.
         """
 
-        return []
+        return ["_image"]
 
     def define_annotation_id(self, annotation: Annotation) -> str:
         """
