@@ -22,6 +22,7 @@ simplify consumption
 
 import json
 from copy import copy
+from itertools import chain
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Sequence, Set, Type, Union, no_type_check
 
@@ -277,10 +278,11 @@ class Page(Image):
     `ImageAnnotation` a corresponding sub class of `ImageAnnotationBaseView` which drives the object towards
     less generic classes with custom attributes that are controlled some `ObjectTypes`.
 
-    :param layout_types: Top level layout objects, e.g. `LayoutType.text` or `LayoutType.table`.
+    :param top_level_text_block_names: Top level layout objects, e.g. `LayoutType.text` or `LayoutType.table`.
     """
 
-    layout_types: List[ObjectTypes]
+    top_level_text_block_names: List[ObjectTypes]
+    text_block_names: Optional[List[ObjectTypes]]
     image_orig: Image
     text_container: ObjectTypes
 
@@ -333,7 +335,7 @@ class Page(Image):
         """
         :return: A list of a layouts.
         """
-        layouts = [layout for layout in self.layout_types if layout != LayoutType.table]
+        layouts = [layout for layout in self.top_level_text_block_names if layout != LayoutType.table]
         return self.get_annotation(category_names=layouts)
 
     @property
@@ -343,6 +345,22 @@ class Page(Image):
         """
         return self.get_annotation(category_names=self.text_container)
 
+    @property
+    def residual_words(self) -> List[ImageAnnotationBaseView]:
+        """
+        :return: A list of a words that have not been assigned to any text block but have a reading order.
+                 Words having this property appear, once `text_containers_to_text_block=True`.
+        """
+        if self.text_block_names is None:
+            return []
+        text_block_anns = self.get_annotation(category_names=self.text_block_names)
+        text_ann_ids = list(
+            chain(*[text_block.get_relationship(Relationships.child) for text_block in text_block_anns])
+        )
+        text_container_anns = self.get_annotation(category_names=self.text_container)
+        residual_words = [ann for ann in text_container_anns if ann.annotation_id not in text_ann_ids]
+        return residual_words
+
     @property
     def tables(self) -> List[ImageAnnotationBaseView]:
         """
@@ -355,7 +373,8 @@ class Page(Image):
         cls,
         image_orig: Image,
         text_container: ObjectTypes,
-        text_block_names: List[ObjectTypes],
+        top_level_text_block_names: List[ObjectTypes],
+        text_block_names: Optional[List[ObjectTypes]] = None,
         base_page: Optional["Page"] = None,
     ) -> "Page":
         """
@@ -363,7 +382,10 @@ class Page(Image):
 
         :param image_orig: `Image` instance to convert
         :param text_container: A LayoutType to get the text from. It will steer the output of `Layout.words`.
-        :param text_block_names: A list of top level layout objects
+        :param top_level_text_block_names: A list of top level layout objects
+        :param text_block_names: name of image annotation that have a relation with text containers (or which might be
+                                 text containers themselves). This is only necessary, when residual text_container (e.g.
+                                 words that have not been assigned to any text block) should be displayed in `page.text`
         :param base_page: For top level objects that are images themselves, pass the page that encloses all objects.
                           In doubt, do not populate this value.
         :return:
@@ -391,17 +413,22 @@ class Page(Image):
                 image_dict = ann_dict["image"]
                 if image_dict:
                     image = Image.from_dict(**image_dict)
-                    layout_ann.image = cls.from_image(image, text_container, text_block_names, page)
+                    layout_ann.image = cls.from_image(
+                        image, text_container, top_level_text_block_names, text_block_names, page
+                    )
             layout_ann.base_page = base_page if base_page is not None else page
             page.dump(layout_ann)
         if summary_dict := img_kwargs.get("_summary"):
             page.summary = SummaryAnnotation.from_dict(**summary_dict)
-        page.layout_types = text_block_names
+        page.top_level_text_block_names = top_level_text_block_names
+        page.text_block_names = text_block_names
         page.text_container = text_container
         return page
 
     def _order(self, block: str) -> List[ImageAnnotationBaseView]:
         blocks_with_order = [layout for layout in getattr(self, block) if layout.reading_order is not None]
+        if self.residual_words:
+            blocks_with_order.extend(self.residual_words)
         blocks_with_order.sort(key=lambda x: x.reading_order)
         return blocks_with_order
 
@@ -413,12 +440,12 @@ class Page(Image):
         :return: Text string
         """
         text: str = ""
-        block = "layouts" if self.layouts else "words"
-        block_content = "text" if block == "layouts" else "characters"
-        block_with_order = self._order(block)
-        linebreak = "\n" if block == "layouts" else " "
-        for block in block_with_order:  # type: ignore
-            text += f"{linebreak}{getattr(block, block_content)}"
+        block_name = "layouts" if self.layouts else "words"
+        block_with_order = self._order(block_name)
+        linebreak = "\n" if block_name == "layouts" else " "
+        for block in block_with_order:
+            block_attr = "text" if block.category_name != LayoutType.word else "characters"
+            text += f"{linebreak}{getattr(block, block_attr)}"
         return text
 
     @property
@@ -444,6 +471,7 @@ class Page(Image):
         show_cells: bool = True,
         show_table_structure: bool = True,
         show_words: bool = False,
+        show_token_class: bool = True,
         interactive: bool = False,
     ) -> Optional[ImageType]:
         """
@@ -463,6 +491,7 @@ class Page(Image):
         :param show_cells: Will display cells within tables. (Only available if `show_tables=True`)
         :param show_table_structure: Will display rows and columns
         :param show_words: Will display bounding boxes around words labeled with token class and bio tag (experimental)
+        :param show_token_class: Will display token class instead of token tags (i.e. token classes with tags)
         :param interactive: If set to True will open an interactive image, otherwise it will return a numpy array that
                             can be displayed differently.
         :return: If interactive will return nothing else a numpy array.
@@ -500,13 +529,23 @@ class Page(Image):
                 all_words.extend(layout.words)
             for word in all_words:
                 box_stack.append(word.bbox)
-                category_names_list.append(str(word.tag) + "-" + str(word.token_class))
+                if show_token_class:
+                    category_names_list.append(str(word.token_class).replace("TokenClasses", ""))
+                else:
+                    category_names_list.append(str(word.token_tag))
 
         if self.image is not None:
             if box_stack:
                 boxes = np.vstack(box_stack)
                 if show_words:
-                    img = draw_boxes(self.image, boxes, category_names_list, font_scale=0.4, rectangle_thickness=1)
+                    img = draw_boxes(
+                        self.image,
+                        boxes,
+                        category_names_list,
+                        color=(255, 222, 173),
+                        font_scale=0.25,
+                        rectangle_thickness=1,
+                    )
                 else:
                     img = draw_boxes(self.image, boxes, category_names_list)
                 img = cv2.resize(img, None, fx=1.3, fy=1.3, interpolation=cv2.INTER_CUBIC)
@@ -524,7 +563,7 @@ class Page(Image):
         """
         :return: A set of registered attributes.
         """
-        return set(PageType).union({"text", "tables", "layouts", "words"})
+        return set(PageType).union({"text", "tables", "layouts", "words", "residual_words"})
 
     def save(
         self,
@@ -532,7 +571,7 @@ class Page(Image):
         highest_hierarchy_only: bool = False,
         path: Optional[Pathlike] = None,
         dry: bool = False,
-    ) -> None:
+    ) -> Optional[JsonDict]:
         """
         Export image as dictionary. As numpy array cannot be serialized :attr:`image` values will be converted into
         base64 encodings.
@@ -540,7 +579,8 @@ class Page(Image):
         :param highest_hierarchy_only: If True it will remove all image attributes of ImageAnnotations
         :param path: Path to save the .json file to
         :param dry: Will run dry, i.e. without saving anything but returning the dict
-        :return: Dict that e.g. can be saved to a file.
+
+        :return: optional dict
         """
         if isinstance(path, str):
             path = Path(path)
@@ -555,6 +595,7 @@ class Page(Image):
         if image_to_json and self.image_orig.image is not None:
             export_dict["_image"] = convert_np_array_to_b64(self.image_orig.image)
         if dry:
-            return None
+            return export_dict
         with open(path_json, "w", encoding="UTF-8") as file:
             json.dump(export_dict, file)
+        return None
