@@ -31,6 +31,7 @@ If not sure use
     print(dataset_instance.dataflow.get_workdir())
 """
 
+from .doclaynet import *
 from .fintabnet import *
 from .funsd import *
 from .iiitar13k import *
@@ -38,6 +39,18 @@ from .layouttest import *
 from .publaynet import *
 from .pubtables1m import *
 from .pubtabnet import *
+from .rvlcdip import *
 from .xfund import *
 
-__all__ = ["Publaynet", "Pubtabnet", "LayoutTest", "Fintabnet", "Xfund", "Funsd", "IIITar13K", "Pubtables1M"]
+__all__ = [
+    "Publaynet",
+    "Pubtabnet",
+    "LayoutTest",
+    "Fintabnet",
+    "Xfund",
+    "Funsd",
+    "IIITar13K",
+    "Pubtables1M",
+    "Rvlcdip",
+    "DocLayNet",
+]
