@@ -21,7 +21,7 @@ from collections import defaultdict, deque
 from typing import Any, List, Optional, Tuple
 
 from ..dataflow import DataFlow, DataFromList, MapData, MultiThreadMapData
-from ..datapoint.page import Page
+from ..datapoint.view import Page
 from ..datasets.base import DatasetCategories
 from ..utils.detection_types import JsonDict
 from ..utils.file_utils import (
@@ -211,7 +211,7 @@ class TedsMetric(MetricBase):
     """
 
     metric = teds_metric  # type: ignore
-    mapper = Page.from_image
+    mapper = Page.from_image  # type: ignore
     structure_only = False
 
     @classmethod
@@ -226,13 +226,13 @@ class TedsMetric(MetricBase):
         gt_dict = defaultdict(list)
         pred_dict = defaultdict(list)
         for dp_gt, dp_pred in zip(dataflow_gt, dataflow_predictions):
-            page_gt = cls.mapper(dp_gt, LayoutType.word, None, [LayoutType.table])
+            page_gt = cls.mapper(dp_gt, LayoutType.word, [LayoutType.table])  # type: ignore
             for table in page_gt.tables:
-                gt_dict[page_gt.uuid].append(table.html)
+                gt_dict[page_gt.image_id].append(table.html)
 
-            page_pred = cls.mapper(dp_pred, LayoutType.word, None, [LayoutType.table])
+            page_pred = cls.mapper(dp_pred, LayoutType.word, [LayoutType.table])  # type: ignore
             for table in page_pred.tables:
-                pred_dict[page_pred.uuid].append(table.html)
+                pred_dict[page_pred.image_id].append(table.html)
 
         gt_list = []
         pred_list = []
