@@ -334,6 +334,55 @@ class ModelCatalog:
             hf_model_name="pytorch_model.bin",
             hf_config_file=["config.json"],
         ),
+        "microsoft/layoutlmv2-base-uncased/pytorch_model.bin": ModelProfile(
+            name="microsoft/layoutlmv2-base-uncased/pytorch_model.bin",
+            description="LayoutLMv2 is an improved version of LayoutLM with new pre-training tasks to model the"
+            " interaction among text, layout, and image in a single multi-modal framework. It outperforms"
+            " strong baselines and achieves new state-of-the-art results on a wide variety of downstream"
+            " visually-rich document understanding tasks, including , including FUNSD (0.7895 → 0.8420),"
+            " CORD (0.9493 → 0.9601), SROIE (0.9524 → 0.9781), Kleister-NDA (0.834 → 0.852), RVL-CDIP"
+            " (0.9443 → 0.9564), and DocVQA (0.7295 → 0.8672). The license is cc-by-nc-sa-4.0",
+            size=[802243295],
+            tp_model=False,
+            config="microsoft/layoutlmv2-base-uncased/config.json",
+            hf_repo_id="microsoft/layoutlmv2-base-uncased",
+            hf_model_name="pytorch_model.bin",
+            hf_config_file=["config.json"],
+        ),
+        "microsoft/layoutxlm-base/pytorch_model.bin": ModelProfile(
+            name="microsoft/layoutxlm-base/pytorch_model.bin",
+            description="Multimodal pre-training with text, layout, and image has achieved SOTA performance for "
+            "visually-rich document understanding tasks recently, which demonstrates the great potential"
+            " for joint learning across different modalities. In this paper, we present LayoutXLM, a"
+            " multimodal pre-trained model for multilingual document understanding, which aims to bridge"
+            " the language barriers for visually-rich document understanding. To accurately evaluate"
+            " LayoutXLM, we also introduce a multilingual form understanding benchmark dataset named XFUN,"
+            " which includes form understanding samples in 7 languages (Chinese, Japanese, Spanish, French,"
+            " Italian, German, Portuguese), and key-value pairs are manually labeled for each language."
+            " Experiment results show that the LayoutXLM model has significantly outperformed the existing"
+            " SOTA cross-lingual pre-trained models on the XFUN dataset. The license is cc-by-nc-sa-4.0",
+            size=[1476537178],
+            tp_model=False,
+            config="microsoft/layoutxlm-base/config.json",
+            hf_repo_id="microsoft/layoutxlm-base",
+            hf_model_name="pytorch_model.bin",
+            hf_config_file=["config.json"],
+        ),
+        "microsoft/layoutlmv3-base/pytorch_model.bin": ModelProfile(
+            name="microsoft/layoutlmv3-base/pytorch_model.bin",
+            description="LayoutLMv3 is a pre-trained multimodal Transformer for Document AI with unified text and"
+            " image masking. The simple unified architecture and training objectives make LayoutLMv3 a"
+            " general-purpose pre-trained model. For example, LayoutLMv3 can be fine-tuned for both"
+            " text-centric tasks, including form understanding, receipt understanding, and document"
+            " visual question answering, and image-centric tasks such as document image classification"
+            " and document layout analysis. The license is cc-by-nc-sa-4.0",
+            size=[501380823],
+            tp_model=False,
+            config="microsoft/layoutlmv3-base/config.json",
+            hf_repo_id="microsoft/layoutlmv3-base",
+            hf_model_name="pytorch_model.bin",
+            hf_config_file=["config.json"],
+        ),
         "fasttext/lid.176.bin": ModelProfile(
             name="fasttext/lid.176.bin",
             description="Fasttext language detection model",
@@ -773,6 +822,7 @@ class ModelDownloadManager:
             force_filename=file_name,
             force_download=force_download,
             use_auth_token=use_auth_token,
+            legacy_cache_layout=True,
         )
         stat_info = os.stat(f_path)
         size = stat_info.st_size
