@@ -18,6 +18,7 @@
 """
 Module for training Huggingface implementation of LayoutLm
 """
+
 import copy
 import json
 import pprint
@@ -30,40 +31,97 @@ from transformers import (
     LayoutLMForSequenceClassification,
     LayoutLMForTokenClassification,
     LayoutLMTokenizerFast,
+    LayoutLMv2Config,
+    LayoutLMv2ForSequenceClassification,
+    LayoutLMv2ForTokenClassification,
+    LayoutLMv3Config,
+    LayoutLMv3ForSequenceClassification,
+    LayoutLMv3ForTokenClassification,
     PretrainedConfig,
     PreTrainedModel,
+    RobertaTokenizerFast,
+    XLMRobertaTokenizerFast,
 )
 from transformers.trainer import Trainer, TrainingArguments
 
 from ..datasets.adapter import DatasetAdapter
 from ..datasets.base import DatasetBase
 from ..datasets.registry import get_dataset
-from ..eval.base import MetricBase
+from ..eval.accmetric import ClassificationMetric
 from ..eval.eval import Evaluator
-from ..extern.hflayoutlm import HFLayoutLmSequenceClassifier, HFLayoutLmTokenClassifier
-from ..mapper.laylmstruct import LayoutLMDataCollator, image_to_layoutlm_features, image_to_raw_layoutlm_features
+from ..extern.hflayoutlm import (
+    HFLayoutLmSequenceClassifier,
+    HFLayoutLmTokenClassifier,
+    HFLayoutLmv2SequenceClassifier,
+    HFLayoutLmv2TokenClassifier,
+    HFLayoutLmv3SequenceClassifier,
+    HFLayoutLmv3TokenClassifier,
+)
+from ..mapper.laylmstruct import LayoutLMDataCollator, image_to_raw_layoutlm_features
 from ..pipe.base import LanguageModelPipelineComponent
+from ..pipe.lm import get_tokenizer_from_architecture
 from ..pipe.registry import pipeline_component_registry
 from ..utils.logger import logger
 from ..utils.settings import DatasetType, LayoutType, ObjectTypes, WordType
 from ..utils.utils import string_to_dict
 
 _ARCHITECTURES_TO_MODEL_CLASS = {
-    "LayoutLMForTokenClassification": LayoutLMForTokenClassification,
-    "LayoutLMForSequenceClassification": LayoutLMForSequenceClassification,
-}
-_ARCHITECTURES_TO_TOKENIZER = {
-    "LayoutLMForTokenClassification": LayoutLMTokenizerFast.from_pretrained("microsoft/layoutlm-base-uncased"),
-    "LayoutLMForSequenceClassification": LayoutLMTokenizerFast.from_pretrained("microsoft/layoutlm-base-uncased"),
+    "LayoutLMForTokenClassification": (LayoutLMForTokenClassification, HFLayoutLmTokenClassifier, PretrainedConfig),
+    "LayoutLMForSequenceClassification": (
+        LayoutLMForSequenceClassification,
+        HFLayoutLmSequenceClassifier,
+        PretrainedConfig,
+    ),
+    "LayoutLMv2ForTokenClassification": (
+        LayoutLMv2ForTokenClassification,
+        HFLayoutLmv2TokenClassifier,
+        LayoutLMv2Config,
+    ),
+    "LayoutLMv2ForSequenceClassification": (
+        LayoutLMv2ForSequenceClassification,
+        HFLayoutLmv2SequenceClassifier,
+        LayoutLMv2Config,
+    ),
 }
+
+
 _MODEL_TYPE_AND_TASK_TO_MODEL_CLASS: Mapping[Tuple[str, ObjectTypes], Any] = {
-    ("layoutlm", DatasetType.sequence_classification): LayoutLMForSequenceClassification,
-    ("layoutlm", DatasetType.token_classification): LayoutLMForTokenClassification,
+    ("layoutlm", DatasetType.sequence_classification): (
+        LayoutLMForSequenceClassification,
+        HFLayoutLmSequenceClassifier,
+        PretrainedConfig,
+    ),
+    ("layoutlm", DatasetType.token_classification): (
+        LayoutLMForTokenClassification,
+        HFLayoutLmTokenClassifier,
+        PretrainedConfig,
+    ),
+    ("layoutlmv2", DatasetType.sequence_classification): (
+        LayoutLMv2ForSequenceClassification,
+        HFLayoutLmv2SequenceClassifier,
+        LayoutLMv2Config,
+    ),
+    ("layoutlmv2", DatasetType.token_classification): (
+        LayoutLMv2ForTokenClassification,
+        HFLayoutLmv2TokenClassifier,
+        LayoutLMv2Config,
+    ),
+    ("layoutlmv3", DatasetType.sequence_classification): (
+        LayoutLMv3ForSequenceClassification,
+        HFLayoutLmv3SequenceClassifier,
+        LayoutLMv3Config,
+    ),
+    ("layoutlmv3", DatasetType.token_classification): (
+        LayoutLMv3ForTokenClassification,
+        HFLayoutLmv3TokenClassifier,
+        LayoutLMv3Config,
+    ),
 }
-_MODEL_TYPE_TO_TOKENIZER = {"layoutlm": LayoutLMTokenizerFast.from_pretrained("microsoft/layoutlm-base-uncased")}
-_DS_TYPE_TO_DD_LM_CLASS: Mapping[ObjectTypes, Any] = {
-    DatasetType.token_classification: HFLayoutLmTokenClassifier,
-    DatasetType.sequence_classification: HFLayoutLmSequenceClassifier,
+_MODEL_TYPE_TO_TOKENIZER = {
+    ("layoutlm", False): LayoutLMTokenizerFast.from_pretrained("microsoft/layoutlm-base-uncased"),
+    ("layoutlmv2", False): LayoutLMTokenizerFast.from_pretrained("microsoft/layoutlm-base-uncased"),
+    ("layoutlmv2", True): XLMRobertaTokenizerFast.from_pretrained("xlm-roberta-base", add_prefix_space=True),
+    ("layoutlmv3", False): RobertaTokenizerFast.from_pretrained("roberta-base", add_prefix_space=True),
 }
 
 
@@ -93,7 +151,7 @@ class LayoutLMTrainer(Trainer):
         self,
         dataset_val: DatasetBase,
         pipeline_component: LanguageModelPipelineComponent,
-        metric: Union[Type[MetricBase], MetricBase],
+        metric: Union[Type[ClassificationMetric], ClassificationMetric],
         **build_eval_kwargs: Union[str, int],
     ) -> None:
         """
@@ -106,7 +164,7 @@ class LayoutLMTrainer(Trainer):
         :param build_eval_kwargs:
         """
 
-        self.evaluator = Evaluator(dataset_val, pipeline_component, metric, num_threads=2)
+        self.evaluator = Evaluator(dataset_val, pipeline_component, metric, num_threads=1)
         assert self.evaluator.pipe_component
         for comp in self.evaluator.pipe_component.pipe_components:
             comp.language_model.model = None  # type: ignore
@@ -138,25 +196,27 @@ class LayoutLMTrainer(Trainer):
         return scores
 
 
-def _get_model_class_and_tokenizer(path_config_json: str, dataset_type: ObjectTypes) -> Tuple[Any, Any]:
+def _get_model_class_and_tokenizer(
+    path_config_json: str, dataset_type: ObjectTypes, use_xlm_tokenizer: bool
+) -> Tuple[Any, Any, Any, Any]:
     with open(path_config_json, "r", encoding="UTF-8") as file:
         config_json = json.load(file)
 
     model_type = config_json.get("model_type")
 
     if architectures := config_json.get("architectures"):
-        model_cls = _ARCHITECTURES_TO_MODEL_CLASS.get(architectures[0])
-        tokenizer_fast = _ARCHITECTURES_TO_TOKENIZER.get(architectures[0])
+        model_cls, model_wrapper_cls, config_cls = _ARCHITECTURES_TO_MODEL_CLASS[architectures[0]]
+        tokenizer_fast = get_tokenizer_from_architecture(architectures[0], use_xlm_tokenizer)
     elif model_type:
-        model_cls = _MODEL_TYPE_AND_TASK_TO_MODEL_CLASS.get((model_type, dataset_type))
-        tokenizer_fast = _MODEL_TYPE_TO_TOKENIZER[model_type]
+        model_cls, model_wrapper_cls, config_cls = _MODEL_TYPE_AND_TASK_TO_MODEL_CLASS[(model_type, dataset_type)]
+        tokenizer_fast = _MODEL_TYPE_TO_TOKENIZER[(model_type, use_xlm_tokenizer)]
     else:
         raise KeyError("model_type and architectures not available in configs")
 
     if not model_cls:
         raise ValueError("model not eligible to run with this framework")
 
-    return model_cls, tokenizer_fast
+    return config_cls, model_cls, model_wrapper_cls, tokenizer_fast
 
 
 def train_hf_layoutlm(
@@ -168,26 +228,38 @@ def train_hf_layoutlm(
     build_train_config: Optional[Sequence[str]] = None,
     dataset_val: Optional[DatasetBase] = None,
     build_val_config: Optional[Sequence[str]] = None,
-    metric: Optional[Union[Type[MetricBase], MetricBase]] = None,
+    metric: Optional[Union[Type[ClassificationMetric], ClassificationMetric]] = None,
     pipeline_component_name: Optional[str] = None,
+    use_xlm_tokenizer: bool = False,
+    use_token_tag: bool = True,
+    segment_positions: Optional[Union[LayoutType, Sequence[LayoutType]]] = None,
 ) -> None:
     """
     Script for fine-tuning LayoutLM models either for sequence classification (e.g. classifying documents) or token
-    classification using HF Trainer and custom evaluation. The theoretical foundation can be taken from
+    classification using HF Trainer and custom evaluation. It currently supports LayoutLM, LayoutLMv2, LayoutLMv3 and
+    LayoutXLM. Training similar but different models like LILT https://arxiv.org/abs/2202.13669 can done by changing a
+    few lines of code regarding the selection of the tokenizer.
+
+    The theoretical foundation can be taken from
 
     https://arxiv.org/abs/1912.13318
 
     This is not the pre-training script.
 
-    In order to remain within the framework of this library, the basic LayoutLM model must be downloaded from the HF-hub
-    in a first step for fine-tuning. Two models are available for this, which are registered in the ModelCatalog:
+    In order to remain within the framework of this library, the base and uncased LayoutLM model must be downloaded
+    from the HF-hub in a first step for fine-tuning.  Models are available for this, which are registered in the
+    ModelCatalog. It is possible to choose one of the following options:
 
     "microsoft/layoutlm-base-uncased/pytorch_model.bin"
+    "microsoft/layoutlmv2-base-uncased/pytorch_model.bin"
+    "microsoft/layoutxlm-base/pytorch_model.bin"
+    "microsoft/layoutlmv3-base/pytorch_model.bin"
 
      and
 
      "microsoft/layoutlm-large-uncased/pytorch_model.bin"
 
+    (You can also choose the large versions of LayoutLMv2 and LayoutXLM but you need to organize the download yourself.)
 
     .. code-block:: python
 
@@ -218,6 +290,15 @@ def train_hf_layoutlm(
     :param metric: A metric to choose for validation.
     :param pipeline_component_name: A pipeline component name to use for validation (e.g. LMSequenceClassifierService or
                                     LMTokenClassifierService.
+    :param use_xlm_tokenizer: This is only necessary if you pass weights of layoutxlm. The config cannot distinguish
+                              between Layoutlmv2 and Layoutxlm, so you need to pass this info explicitly.
+    :param use_token_tag: Will only be used for dataset_type="token_classification". If use_token_tag=True, will use
+                          labels from sub category `WordType.token_tag` (with `B,I,O` suffix), otherwise
+                          `WordType.token_class`.
+    :param segment_positions: Using bounding boxes of segment instead of words improves model accuracy significantly.
+                              Choose a single or a sequence of layout segments to use their bounding boxes. Note, that
+                              the layout segments need to have a child-relationship with words. If a word does not
+                              appear as child, it will use the word bounding box.
     """
 
     build_train_dict: Dict[str, str] = {}
@@ -243,20 +324,37 @@ def train_hf_layoutlm(
     if dataset_type == DatasetType.sequence_classification:
         categories_dict_name_as_key = dataset_train.dataflow.categories.get_categories(as_dict=True, name_as_key=True)
     elif dataset_type == DatasetType.token_classification:
-        categories_dict_name_as_key = dataset_train.dataflow.categories.get_sub_categories(
-            categories=LayoutType.word,
-            sub_categories={LayoutType.word: [WordType.token_tag]},
-            keys=False,
-            values_as_dict=True,
-            name_as_key=True,
-        )[LayoutType.word][WordType.token_tag]
+        if use_token_tag:
+            categories_dict_name_as_key = dataset_train.dataflow.categories.get_sub_categories(
+                categories=LayoutType.word,
+                sub_categories={LayoutType.word: [WordType.token_tag]},
+                keys=False,
+                values_as_dict=True,
+                name_as_key=True,
+            )[LayoutType.word][WordType.token_tag]
+        else:
+            categories_dict_name_as_key = dataset_train.dataflow.categories.get_sub_categories(
+                categories=LayoutType.word,
+                sub_categories={LayoutType.word: [WordType.token_class]},
+                keys=False,
+                values_as_dict=True,
+                name_as_key=True,
+            )[LayoutType.word][WordType.token_class]
     else:
         raise ValueError("Dataset type not supported for training")
 
+    config_cls, model_cls, model_wrapper_cls, tokenizer_fast = _get_model_class_and_tokenizer(
+        path_config_json, dataset_type, use_xlm_tokenizer
+    )
+    image_to_raw_layoutlm_kwargs = {"dataset_type": dataset_type, "use_token_tag": use_token_tag}
+    if segment_positions:
+        image_to_raw_layoutlm_kwargs["segment_positions"] = segment_positions
+    image_to_raw_layoutlm_kwargs.update(model_wrapper_cls.default_kwargs_for_input_mapping())
     dataset = DatasetAdapter(
         dataset_train,
         True,
-        image_to_raw_layoutlm_features(categories_dict_name_as_key, dataset_type),
+        image_to_raw_layoutlm_features(**image_to_raw_layoutlm_kwargs),
+        use_token_tag,
         **build_train_dict,
     )
 
@@ -276,9 +374,6 @@ def train_hf_layoutlm(
         "eval_steps": 100,
     }
 
-    if isinstance(dataset_train, str):
-        dataset_train = get_dataset(dataset_train)
-
     # We allow to overwrite the default setting by the user.
     for conf in config_overwrite:
         key, val = conf.split("=", maxsplit=1)
@@ -300,26 +395,31 @@ def train_hf_layoutlm(
     arguments = TrainingArguments(**conf_dict)
     logger.info("Config: \n %s", str(arguments.to_dict()), arguments.to_dict())
 
-    model_cls, tokenizer_fast = _get_model_class_and_tokenizer(path_config_json, dataset_type)
-
     id2label = {int(k) - 1: v for v, k in categories_dict_name_as_key.items()}
 
     logger.info("Will setup a head with the following classes\n %s", pprint.pformat(id2label, width=100, compact=True))
 
-    config = PretrainedConfig.from_pretrained(pretrained_model_name_or_path=path_config_json, id2label=id2label)
+    config = config_cls.from_pretrained(pretrained_model_name_or_path=path_config_json, id2label=id2label)
     model = model_cls.from_pretrained(pretrained_model_name_or_path=path_weights, config=config)
     data_collator = LayoutLMDataCollator(tokenizer_fast, return_tensors="pt")
     trainer = LayoutLMTrainer(model, arguments, data_collator, dataset)
 
     if arguments.evaluation_strategy in (IntervalStrategy.STEPS,):
-        dd_model_cls = _DS_TYPE_TO_DD_LM_CLASS[dataset_type]
+        assert metric is not None  # silence mypy
         if dataset_type == DatasetType.sequence_classification:
             categories = dataset_val.dataflow.categories.get_categories(filtered=True)  # type: ignore
         else:
-            categories = dataset_val.dataflow.categories.get_sub_categories(  # type: ignore
-                categories=LayoutType.word, sub_categories={LayoutType.word: [WordType.token_tag]}, keys=False
-            )[LayoutType.word][WordType.token_tag]
-        dd_model = dd_model_cls(
+            if use_token_tag:
+                categories = dataset_val.dataflow.categories.get_sub_categories(  # type: ignore
+                    categories=LayoutType.word, sub_categories={LayoutType.word: [WordType.token_tag]}, keys=False
+                )[LayoutType.word][WordType.token_tag]
+                metric.set_categories(category_names=LayoutType.word, sub_category_names={"word": ["token_tag"]})
+            else:
+                categories = dataset_val.dataflow.categories.get_sub_categories(  # type: ignore
+                    categories=LayoutType.word, sub_categories={LayoutType.word: [WordType.token_class]}, keys=False
+                )[LayoutType.word][WordType.token_class]
+                metric.set_categories(category_names=LayoutType.word, sub_category_names={"word": ["token_class"]})
+        dd_model = model_wrapper_cls(
             path_config_json=path_config_json,
             path_weights=path_weights,
             categories=categories,
@@ -327,9 +427,9 @@ def train_hf_layoutlm(
         )
         pipeline_component_cls = pipeline_component_registry.get(pipeline_component_name)
         if dataset_type == DatasetType.sequence_classification:
-            pipeline_component = pipeline_component_cls(tokenizer_fast, dd_model, image_to_layoutlm_features)
+            pipeline_component = pipeline_component_cls(tokenizer_fast, dd_model)
         else:
-            pipeline_component = pipeline_component_cls(tokenizer_fast, dd_model, image_to_layoutlm_features, True)
+            pipeline_component = pipeline_component_cls(tokenizer_fast, dd_model, use_other_as_default_category=True)
         assert isinstance(pipeline_component, LanguageModelPipelineComponent)
 
         trainer.setup_evaluator(dataset_val, pipeline_component, metric, **build_val_dict)  # type: ignore
