@@ -36,12 +36,16 @@ from tensorpack.callbacks import (
 )
 
 # todo: check how dataflow import is directly possible without having AssertionError
-from tensorpack.dataflow import DataFlow, DataFromList, MapData, MultiProcessMapData, imgaug
+from tensorpack.dataflow import ProxyDataFlow, imgaug
 from tensorpack.input_source import QueueInput
 from tensorpack.tfutils import SmartInit
 from tensorpack.train import SyncMultiGPUTrainerReplicated, TrainConfig, launch_train_with_config
 from tensorpack.utils import logger
 
+from ..dataflow.base import DataFlow
+from ..dataflow.common import MapData
+from ..dataflow.parallel_map import MultiProcessMapData
+from ..dataflow.serialize import DataFromList
 from ..datasets.base import DatasetBase
 from ..eval.base import MetricBase
 from ..eval.registry import metric_registry
@@ -67,7 +71,7 @@ from ..utils.utils import string_to_dict
 __all__ = ["train_faster_rcnn"]
 
 
-class LoadAugmentAddAnchors:  # pylint: disable=R0903
+class LoadAugmentAddAnchors:
     """
     A helper class for default mapping func: load_augment_add_anchors.
     """
@@ -175,7 +179,7 @@ def get_train_dataflow(
         )
     else:
         df = MapData(df, load_augment_anchors)
-    return df
+    return ProxyDataFlow(df)
 
 
 def train_faster_rcnn(
@@ -249,7 +253,7 @@ def train_faster_rcnn(
     # This is what's commonly referred to as "epochs"
 
     try:
-        size = train_dataflow.size()
+        size = len(train_dataflow)
         total_passes = config.TRAIN.LR_SCHEDULE[-1] * 8 / size
         logger.info("Total passes of the training set is: %i", total_passes)
 
