@@ -22,7 +22,7 @@ Module for funcs and constants that maintain general settings
 import os
 from enum import Enum
 from pathlib import Path
-from typing import Tuple, Union
+from typing import Dict, List, Optional, Tuple, Union
 
 import catalogue  # type: ignore
 
@@ -179,11 +179,13 @@ class BioTag(ObjectTypes):
     begin = "B"
     inside = "I"
     outside = "O"
+    single = "S"
+    end = "E"
 
 
 @object_types_registry.register("TokenClassWithTag")
 class TokenClassWithTag(ObjectTypes):
-    """Types for token classes with tags, e.g. B-ANSWER"""
+    """Types for token classes with tags, e.g. B-answer"""
 
     b_answer = "B-answer"
     b_header = "B-header"
@@ -286,10 +288,16 @@ class DatasetType(ObjectTypes):
 _TOKEN_AND_TAG_TO_TOKEN_CLASS_WITH_TAG = {
     (TokenClasses.header, BioTag.begin): TokenClassWithTag.b_header,
     (TokenClasses.header, BioTag.inside): TokenClassWithTag.i_header,
+    (TokenClasses.header, BioTag.end): TokenClassWithTag.e_header,
+    (TokenClasses.header, BioTag.single): TokenClassWithTag.s_header,
     (TokenClasses.answer, BioTag.begin): TokenClassWithTag.b_answer,
     (TokenClasses.answer, BioTag.inside): TokenClassWithTag.i_answer,
+    (TokenClasses.answer, BioTag.end): TokenClassWithTag.e_answer,
+    (TokenClasses.answer, BioTag.single): TokenClassWithTag.s_answer,
     (TokenClasses.question, BioTag.begin): TokenClassWithTag.b_question,
     (TokenClasses.question, BioTag.inside): TokenClassWithTag.i_question,
+    (TokenClasses.question, BioTag.end): TokenClassWithTag.e_question,
+    (TokenClasses.question, BioTag.single): TokenClassWithTag.s_question,
     (TokenClasses.other, BioTag.outside): BioTag.outside,
     (TokenClasses.header, BioTag.outside): BioTag.outside,
     (TokenClasses.answer, BioTag.outside): BioTag.outside,
@@ -311,14 +319,16 @@ def token_class_tag_to_token_class_with_tag(token: ObjectTypes, tag: ObjectTypes
     raise TypeError("Token must be of type TokenClasses and tag must be of type BioTag")
 
 
-def token_class_with_tag_to_token_class_and_tag(token_class_with_tag: ObjectTypes) -> Tuple[ObjectTypes, ObjectTypes]:
+def token_class_with_tag_to_token_class_and_tag(
+    token_class_with_tag: ObjectTypes,
+) -> Optional[Tuple[ObjectTypes, ObjectTypes]]:
     """
     This is the reverse mapping from TokenClassWithTag members to TokenClasses and BioTag
 
     :param token_class_with_tag: TokenClassWithTag member
     :return: Tuple of TokenClasses member and BioTag member
     """
-    return {val: key for key, val in _TOKEN_AND_TAG_TO_TOKEN_CLASS_WITH_TAG.items()}[token_class_with_tag]
+    return {val: key for key, val in _TOKEN_AND_TAG_TO_TOKEN_CLASS_WITH_TAG.items()}.get(token_class_with_tag)
 
 
 _ALL_TYPES_DICT = {}
@@ -335,6 +345,41 @@ def update_all_types_dict() -> None:
         _ALL_TYPES_DICT.update({e.value: e for e in obj})
 
 
+_OLD_TO_NEW_OBJ_TYPE: Dict[str, str] = {
+    "DOC_CLASS": "document_type",
+    "CHARS": "characters",
+    "BIO_TAG": "tag",
+    "B-ANSWER": "B-answer",
+    "B-HEADER": "B-header",
+    "B-QUESTION": "B-question",
+    "E-ANSWER": "E-answer",
+    "E-HEADER": "E-header",
+    "E-QUESTION": "E-question",
+    "I-ANSWER": "I-answer",
+    "I-HEADER": "I-header",
+    "I-QUESTION": "I-question",
+    "S-ANSWER": "S-answer",
+    "S-HEADER": "S-header",
+    "S-QUESTION": "S-question",
+}
+
+
+def _get_new_obj_type_str(obj_type: str) -> str:
+    return _OLD_TO_NEW_OBJ_TYPE.get(obj_type, obj_type)
+
+
+_BLACK_LIST: List[str] = ["B", "I", "O", "E", "S"]
+
+
+def _get_black_list() -> List[str]:
+    return _BLACK_LIST
+
+
+def update_black_list(item: str) -> None:
+    """Updates the black list, i.e. set of elements that must not be lowered"""
+    _BLACK_LIST.append(item)
+
+
 def get_type(obj_type: Union[str, ObjectTypes]) -> ObjectTypes:
     """Get an object type property from a given string. Does nothing if an ObjectType is passed
 
@@ -343,6 +388,11 @@ def get_type(obj_type: Union[str, ObjectTypes]) -> ObjectTypes:
     """
     if isinstance(obj_type, ObjectTypes):
         return obj_type
+    obj_type = _get_new_obj_type_str(obj_type)
+    if obj_type.startswith(("B-", "E-", "I-", "S-")):
+        obj_type = obj_type[:2] + obj_type[2:].lower()
+    elif obj_type not in _get_black_list():
+        obj_type = obj_type.lower()
     return_value = _ALL_TYPES_DICT.get(obj_type)
     if return_value is None:
         raise KeyError(f"String {obj_type} does not correspond to a registered ObjectType")
