@@ -24,6 +24,7 @@ from pytest import mark
 
 from deepdoctection.datapoint import CategoryAnnotation
 from deepdoctection.utils import get_uuid
+from deepdoctection.utils.settings import get_type
 
 from .conftest import CatAnn
 
@@ -34,6 +35,7 @@ class TestCategoryAnnotation:
     """
 
     @staticmethod
+    @mark.basic
     @mark.parametrize(
         "external_id,expected",
         [
@@ -55,6 +57,7 @@ class TestCategoryAnnotation:
         assert test_cat.annotation_id == expected
 
     @staticmethod
+    @mark.basic
     def test_dump_sup_cat_and_check_ann_id() -> None:
         """
         Sub categories are dumped to category instance and annotation ids are correctly assigned
@@ -66,21 +69,22 @@ class TestCategoryAnnotation:
         sub_cat_2 = CategoryAnnotation(category_name="BAZ", category_id="3")
 
         # Act
-        cat.dump_sub_category("bak", sub_cat_1)
-        cat.dump_sub_category("baz", sub_cat_2, "c822f8c3-1148-30c4-90eb-cb4896b1ebe5")
+        cat.dump_sub_category(get_type("bak"), sub_cat_1)
+        cat.dump_sub_category(get_type("baz"), sub_cat_2, "c822f8c3-1148-30c4-90eb-cb4896b1ebe5")
 
-        export_sub_cat_1 = cat.get_sub_category("bak")
-        export_sub_cat_2 = cat.get_sub_category("baz")
+        export_sub_cat_1 = cat.get_sub_category(get_type("bak"))
+        export_sub_cat_2 = cat.get_sub_category(get_type("baz"))
 
         # Assert
         if export_sub_cat_1 is not None and export_sub_cat_2 is not None:
-            tmp_annotation_id_cat = "6251d1c6-856f-3eac-b73e-db1d300852a3"
-            assert export_sub_cat_1.annotation_id == get_uuid("BAK2" + tmp_annotation_id_cat)
+            tmp_annotation_id_cat = "8295618a-978d-3aad-bea9-b4faa3061ab6"
+            assert export_sub_cat_1.annotation_id == get_uuid("TestType.BAK2" + tmp_annotation_id_cat)
             assert export_sub_cat_2.annotation_id == get_uuid(
-                "BAZ3" + tmp_annotation_id_cat, "c822f8c3-1148-30c4-90eb-cb4896b1ebe5"
+                "TestType.BAZ3" + tmp_annotation_id_cat, "c822f8c3-1148-30c4-90eb-cb4896b1ebe5"
             )
 
     @staticmethod
+    @mark.basic
     def test_dump_sub_cat_with_external_id() -> None:
         """
         Sub categories are dumped to category instance and external category ids will be annotation ids
@@ -92,15 +96,16 @@ class TestCategoryAnnotation:
             category_name="FOOBAK", category_id="2", external_id="c822f8c3-1148-30c4-90eb-cb4896b1ebe5"
         )
         # Act
-        cat.dump_sub_category("bak", sub_cat_1)
+        cat.dump_sub_category(get_type("bak"), sub_cat_1)
 
-        export_sub_cat_1 = cat.get_sub_category("bak")
+        export_sub_cat_1 = cat.get_sub_category(get_type("bak"))
 
         # Assert
         if export_sub_cat_1 is not None:
             assert export_sub_cat_1.annotation_id == "c822f8c3-1148-30c4-90eb-cb4896b1ebe5"
 
     @staticmethod
+    @mark.basic
     def test_remove_sub_cat() -> None:
         """
         Existing sub categories are correctly removed
@@ -109,11 +114,11 @@ class TestCategoryAnnotation:
         # Arrange
         cat = CategoryAnnotation(category_name="FOO", category_id="1")
         sub_cat_1 = CategoryAnnotation(category_name="BAK", category_id="2")
-        cat.dump_sub_category("bak", sub_cat_1)
+        cat.dump_sub_category(get_type("bak"), sub_cat_1)
 
         # Act
-        cat.remove_sub_category("bak")
+        cat.remove_sub_category(get_type("bak"))
 
         # Assert
         with pytest.raises(Exception):
-            cat.get_sub_category("bak")
+            cat.get_sub_category(get_type("bak"))
