@@ -44,7 +44,7 @@ class TestCocoMetric:
         self.dataflow_pr = DataFromList(dp_list)
         self.categories = get_image_results().get_dataset_categories()
 
-    @mark.full
+    @mark.basic
     def test_coco_metric_returns_correct_distance(self) -> None:
         """
         when testing datapoint against itself, evaluation returns full score except when some areas do not exist
@@ -65,7 +65,7 @@ class TestCocoMetric:
 
         assert_allclose(output, expected_output, atol=1e-10)  # type: ignore
 
-    @mark.full
+    @mark.basic
     def test_when_params_change_coco_metric_returns_correct_distance(self) -> None:
         """
         when parameters are changed then coco metric return correct distance
@@ -95,7 +95,7 @@ class TestCocoMetric:
         # Clean-up
         CocoMetric._params = {}  # pylint: disable=W0212
 
-    @mark.full
+    @mark.basic
     def test_when_f1_score_coco_metric_returns_correct_distance(self) -> None:
         """
         when f1_score = True is set then coco metric returns correct distance
